@@ -1,7 +1,7 @@
 /*
  *  Mathlib - A Mathematical Function Library
  *  Copyright (C) 1998  Ross Ihaka
- *  Copyright (C) 2000 The R Development Core Team
+ *  Copyright (C) 2000-7 The R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,15 +14,14 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  along with this program; if not, a copy is available at
+ *  http://www.r-project.org/Licenses/
  */
 
 #include "nmath.h"
-#undef i1mach
+#include <limits.h>
 
-/* This is (naughtily) used by port.c in package stats */
-int jags_i1mach(int i)
+attribute_hidden int jags_i1mach(int i)
 {
     switch(i) {
 
@@ -51,10 +50,3 @@ int jags_i1mach(int i)
     default: return 0;
     }
 }
-
-/*
-int F77_NAME(i1mach)(int *i)
-{
-    return Rf_i1mach(*i);
-}
-*/
