@@ -12,7 +12,8 @@ class DiscreteDSum : public RWDSum
 {
 public:
     DiscreteDSum(GraphView const *gv, unsigned int chain);
-    void step(std::vector<double> &value, double s, RNG *rng) const;
+    void step(std::vector<double> &value, unsigned int nrow,
+	      unsigned int ncol, double s, RNG *rng) const;
     std::string name() const;
 };
 
